@@ -65,14 +65,14 @@ def list_plugins(custom_plugins_folder):
 @click.option('--summary', is_flag=True)
 @click.option('-o', '--output-file', type=click.Path(exists=False))
 @click.option('--ignore-info', is_flag=True, help="Ignore information vulnerabilities")
-@click.option('--hostname-resolution', is_flag=True, help="Resolve hostname")
+@click.option('-drh', '--dont-resolve-hostname', is_flag=True, help="Dont resolve hostname", default=False)
 def process_report(report_file, plugin_id, custom_plugins_folder, summary, output_file, ignore_info,
-                   hostname_resolution):
+                   dont_resolve_hostname):
     if not os.path.isfile(report_file):
         click.echo(click.style(f"File {report_file} Don't Exists", fg="red"), err=True)
     else:
         plugins_manager = PluginsManager(custom_plugins_folder, ignore_info=ignore_info,
-                                         hostname_resolution=hostname_resolution)
+                                         hostname_resolution=not dont_resolve_hostname)
         analyzer = ReportAnalyzer(plugins_manager)
         if plugin_id:
             plugin = plugins_manager.get_plugin(plugin_id)
