@@ -152,8 +152,9 @@ class CommandAnalyzer:
 
 class PluginsManager:
 
-    def __init__(self, custom_plugins_folder=None, ignore_info=False):
+    def __init__(self, custom_plugins_folder=None, ignore_info=False, hostname_resolution=True):
         self.ignore_info = ignore_info
+        self.hostname_resolution = hostname_resolution
         self.plugins = {}
         self.plugin_modules = {}
         self._load_plugins(custom_plugins_folder)
@@ -216,7 +217,7 @@ class PluginsManager:
         plugin = None
         plugin_id = plugin_id.lower()
         if plugin_id in self.plugin_modules:
-            plugin = self.plugin_modules[plugin_id].createPlugin(self.ignore_info)
+            plugin = self.plugin_modules[plugin_id].createPlugin(self.ignore_info, self.hostname_resolution)
         else:
             logger.debug("Unknown Plugin: %s", plugin_id)
         return plugin
@@ -224,4 +225,4 @@ class PluginsManager:
     def get_plugins(self):
         for plugin_id, plugin_module in self.plugin_modules.items():
             logger.debug("Instance Plugin: %s", plugin_id)
-            yield plugin_id, plugin_module.createPlugin(self.ignore_info)
+            yield plugin_id, plugin_module.createPlugin(self.ignore_info, self.hostname_resolution)
