@@ -16,6 +16,7 @@ import zipfile
 from collections import defaultdict
 from datetime import datetime
 from pathlib import Path
+import socket
 
 # Related third party imports
 import pytz
@@ -34,11 +35,12 @@ class PluginBase:
     # TODO: Add class generic identifier
     class_signature = "PluginBase"
 
-    def __init__(self, ignore_info=False):
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
         # Must be unique. Check that there is not
         # an existent plugin with the same id.
         # TODO: Make script that list current ids.
         self.ignore_info = ignore_info
+        self.hostname_resolution = hostname_resolution
         self.id = None
         self.auto_load = True
         self._rid = id(self)
@@ -83,6 +85,21 @@ class PluginBase:
         temp_file_path = os.path.join(temp_dir, temp_filename)
         return temp_file_path
 
+    def resolve_hostname(self, hostname):
+        if not self.hostname_resolution:
+            return hostname
+        try:
+            socket.inet_aton(hostname)  # is already an ip
+            return hostname
+        except OSError:
+            pass
+        try:
+            ip_address = socket.gethostbyname(hostname)
+        except Exception as e:
+            return hostname
+        else:
+            return ip_address
+
     @staticmethod
     def get_utctimestamp(date):
         if date is not None:
@@ -593,8 +610,8 @@ class PluginCustomOutput(PluginBase):
 
 
 class PluginByExtension(PluginBase):
-    def __init__(self, ignore_info=False):
-        super().__init__(ignore_info)
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
+        super().__init__(ignore_info, hostname_resolution)
         self.extension = []
 
     def report_belongs_to(self, extension="", **kwargs):
@@ -609,8 +626,8 @@ class PluginByExtension(PluginBase):
 
 class PluginXMLFormat(PluginByExtension):
 
-    def __init__(self, ignore_info=False):
-        super().__init__(ignore_info)
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
+        super().__init__(ignore_info, hostname_resolution)
         self.identifier_tag = []
         self.identifier_tag_attributes = {}
         self.extension = ".xml"
@@ -631,8 +648,8 @@ class PluginXMLFormat(PluginByExtension):
 
 class PluginJsonFormat(PluginByExtension):
 
-    def __init__(self, ignore_info=False):
-        super().__init__(ignore_info)
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
+        super().__init__(ignore_info, hostname_resolution)
         self.json_keys = set()
         self.extension = ".json"
 
@@ -648,8 +665,8 @@ class PluginJsonFormat(PluginByExtension):
 
 class PluginMultiLineJsonFormat(PluginByExtension):
 
-    def __init__(self, ignore_info=False):
-        super().__init__(ignore_info)
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
+        super().__init__(ignore_info, hostname_resolution)
         self.json_keys = set()
         self.extension = ".json"
 
@@ -672,8 +689,8 @@ class PluginMultiLineJsonFormat(PluginByExtension):
 
 class PluginCSVFormat(PluginByExtension):
 
-    def __init__(self, ignore_info=False):
-        super().__init__(ignore_info)
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
+        super().__init__(ignore_info, hostname_resolution)
         self.extension = ".csv"
         self.csv_headers = set()
 
@@ -692,8 +709,8 @@ class PluginCSVFormat(PluginByExtension):
 
 class PluginZipFormat(PluginByExtension):
 
-    def __init__(self, ignore_info=False):
-        super().__init__(ignore_info)
+    def __init__(self, ignore_info=False, hostname_resolution=True, *args, **kwargs):
+        super().__init__(ignore_info, hostname_resolution)
         self.extension = ".zip"
         self.files_list = set()
 
