@@ -9,7 +9,6 @@ import xml.etree.ElementTree as ET
 from urllib.parse import urlparse
 
 from faraday_plugins.plugins.plugin import PluginXMLFormat
-from faraday_plugins.plugins.plugins_utils import resolve_hostname
 
 __author__ = 'Ezequiel Tavella'
 __copyright__ = 'Copyright 2016, Faraday Project'
@@ -165,9 +164,9 @@ class Issue():
         data = request.findtext("method", "").upper()
         data += f" {request.findtext('url', '')}"
         for h in request.findall('headers/header'):
-            data += "\n%s: %s" % (h.get('name'), h.get('value'))
+            data += f"\n{h.get('name')}: {h.get('value')}"
         if request.findtext('body',""):
-            data += "\n%s" % request.findtext('body',"")
+            data += f"\n{request.findtext('body','')}"
         return data
 
     @staticmethod
@@ -420,9 +419,9 @@ class ArachniPlugin(PluginXMLFormat):
 
         self.hostname = self.getHostname(parser.system.url)
         if parser.plugins.ip:
-            self.address = resolve_hostname(parser.plugins.ip)
+            self.address = self.resolve_hostname(parser.plugins.ip)
         else:
-            self.address = resolve_hostname(self.hostname)
+            self.address = self.resolve_hostname(self.hostname)
 
         # Create host and interface
         host_id = self.createAndAddHost(self.address, hostnames=[self.hostname])
@@ -495,9 +494,9 @@ class ArachniPlugin(PluginXMLFormat):
         # add reporter
         cmd_prefix_match = re.match(r"(^.*?)arachni ", command_string)
         cmd_prefix = cmd_prefix_match.group(1)
-        reporter_cmd = "%s%s --reporter=\"xml:outfile=%s\" \"%s\"" % (cmd_prefix, "arachni_reporter", xml_file_path,
+        reporter_cmd = "{}{} --reporter=\"xml:outfile={}\" \"{}\"".format(cmd_prefix, "arachni_reporter", xml_file_path,
                                                                       afr_file_path)
-        return "/usr/bin/env -- bash -c '%s  2>&1 && if [ -e \"%s\" ];then %s 2>&1;fi'" % (main_cmd,
+        return "/usr/bin/env -- bash -c '{}  2>&1 && if [ -e \"{}\" ];then {} 2>&1;fi'".format(main_cmd,
                                                                                            afr_file_path,
                                                                                            reporter_cmd)
 
@@ -517,5 +516,5 @@ class ArachniPlugin(PluginXMLFormat):
         return self.hostname
 
 
-def createPlugin(ignore_info=False):
-    return ArachniPlugin(ignore_info=ignore_info)
+def createPlugin(ignore_info=False, hostname_resolution=True):
+    return ArachniPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
