@@ -94,5 +94,5 @@ class SonarQubeAPIPlugin(PluginJsonFormat):
             )
 
 
-def createPlugin(ignore_info=False):
-    return SonarQubeAPIPlugin(ignore_info=ignore_info)
+def createPlugin(ignore_info=False, hostname_resolution=True):
+    return SonarQubeAPIPlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
