@@ -98,5 +98,5 @@ class WhitesourcePlugin(PluginJsonFormat):
                     )
 
 
-def createPlugin(ignore_info=False):
-    return WhitesourcePlugin(ignore_info=ignore_info)
+def createPlugin(ignore_info=False, hostname_resolution=True):
+    return WhitesourcePlugin(ignore_info=ignore_info, hostname_resolution=hostname_resolution)
